"use strict";

var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");

var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");

_Object$defineProperty(exports, "__esModule", {
  value: true
});

exports.default = void 0;

var _reduce = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/reduce"));

var _keys = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/keys"));

var _padEnd = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/pad-end"));

var _trimEnd = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/trim-end"));

var _forEach = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/for-each"));

var _toolLib = require("@kettil/tool-lib");

var _chalk = _interopRequireDefault(require("chalk"));

var _spinner = require("./spinner");

var _context;

const levels = {
  log: msg => msg,
  error: _chalk.default.red,
  info: _chalk.default.green,
  debug: _chalk.default.blue
};
const maxLevelLength = (0, _reduce.default)(_context = (0, _keys.default)(levels)).call(_context, (p, c) => Math.max(p, c.length), 0);

const getMessageLevel = level => {
  var _context2;

  return levels[level]((0, _padEnd.default)(_context2 = level.toUpperCase()).call(_context2, maxLevelLength));
};

const write = (type, message) => {
  process[type].write(`${(0, _trimEnd.default)(message).call(message)}\n`);
};

const logging = (level, type) => msg => {
  const resume = (0, _spinner.spinnerBreak)();
  const messages = (0, _toolLib.isArray)(msg) ? msg : msg.replace(/\n$/, '').split('\n');
  (0, _forEach.default)(messages).call(messages, m => {
    write(type, `[${new Date().toISOString()}] ${level}: ${m}`);
  });
  resume();
};

const log = msg => write('stdout', (0, _toolLib.isArray)(msg) ? msg.join('\n') : msg);

const logger = ({
  verbose,
  vvv
}) => {
  const error = logging(getMessageLevel('error'), 'stderr');
  const info = logging(getMessageLevel('info'), 'stdout');
  const debug = logging(getMessageLevel('debug'), 'stdout');

  if (vvv) {
    return {
      log,
      error,
      info,
      debug
    };
  }

  if (verbose) {
    return {
      log,
      error,
      info,
      debug: _toolLib.dummy
    };
  }

  return {
    log,
    error: _toolLib.dummy,
    info: _toolLib.dummy,
    debug: _toolLib.dummy
  };
};

var _default = logger;
exports.default = _default;