"use strict";

var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");

var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");

_Object$defineProperty(exports, "__esModule", {
  value: true
});

exports.handler = exports.builder = exports.desc = exports.command = void 0;

var _packageLoad = _interopRequireDefault(require("../actions/npm/packageLoad"));

var _babel = _interopRequireDefault(require("../actions/tools/babel"));

var _tsc = _interopRequireDefault(require("../actions/tools/tsc"));

var _webpack = _interopRequireDefault(require("../actions/tools/webpack"));

var _spinner = require("../lib/cli/spinner");

var _yargs = require("../lib/cli/yargs");

var _logo = _interopRequireDefault(require("../lib/logo"));

const command = 'build';
exports.command = command;
const desc = 'Run the code quality tools';
exports.desc = desc;
const options = {
  group: `${command}-Options`
};
const builder = (0, _yargs.builderDefault)(command, yargs => yargs.options({
  ci: { ...options,
    type: 'boolean',
    default: false,
    describe: 'Run it in CI mode'
  }
}));
exports.builder = builder;

const handler = async argv => {
  try {
    const isPrivate = await (0, _packageLoad.default)(argv, {
      key: 'private'
    });

    if (argv.ci) {
      if (isPrivate !== true) {
        await (0, _tsc.default)(argv, {
          mode: 'type-create'
        });
      }

      await (0, _babel.default)(argv);
      await (0, _webpack.default)(argv);
    } else {
      await (0, _logo.default)();
      argv.log.debug(['Paths:', `▸ cwd: ${argv.cwd}`, `▸ cfg: ${argv.cfg}`, `▸ tpl: ${argv.tpl}`, '']);

      if (isPrivate !== true) {
        await (0, _spinner.spinnerAction)((0, _tsc.default)(argv, {
          mode: 'type-create'
        }), 'Typescript');
      }

      await (0, _spinner.spinnerAction)((0, _babel.default)(argv), 'Babel');
      await (0, _spinner.spinnerAction)((0, _webpack.default)(argv), 'Webpack');
    }
  } catch (error) {
    (0, _yargs.errorHandler)(argv, error);
  }
};

exports.handler = handler;