"use strict";

var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");

var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");

_Object$defineProperty(exports, "__esModule", {
  value: true
});

exports.handler = exports.builder = exports.desc = exports.command = void 0;

var _path = require("path");

var _add = _interopRequireDefault(require("../actions/git/add"));

var _commit = _interopRequireDefault(require("../actions/git/commit"));

var _init = _interopRequireDefault(require("../actions/git/init"));

var _init2 = _interopRequireDefault(require("../actions/npm/init"));

var _packageLoad = _interopRequireDefault(require("../actions/npm/packageLoad"));

var _packageUpdate = _interopRequireDefault(require("../actions/npm/packageUpdate"));

var _spinner = require("../lib/cli/spinner");

var _yargs = require("../lib/cli/yargs");

var _access = _interopRequireDefault(require("../lib/cmd/access"));

var _logo = _interopRequireDefault(require("../lib/logo"));

var _dependencie = _interopRequireDefault(require("./init/dependencie"));

var _io = _interopRequireDefault(require("./init/io"));

var _settings = _interopRequireDefault(require("./init/settings"));

var _template = _interopRequireDefault(require("./init/template"));

const command = 'init';
exports.command = command;
const desc = 'Initializes the project';
exports.desc = desc;
const args = {
  type: 'boolean',
  default: false,
  group: `${command}-Options:`
};
const builder = (0, _yargs.builderDefault)(command, yargs => yargs.options({
  package: { ...args,
    alias: 'p',
    desc: 'Project is created as a package'
  },
  cli: { ...args,
    alias: 'c',
    implies: 'package',
    desc: 'Extends the package with CLI features'
  },
  github: {
    type: 'string',
    implies: 'package',
    desc: 'Github username',
    group: `${command}-Options:`
  },
  // conflict with cli
  // react: { ...args, alias: 'r', default: undefined, desc: 'React will be installed', },
  noCommit: { ...args,
    desc: 'No initial commit is executed at the end'
  }
}));
exports.builder = builder;

const handler = async argv => {
  try {
    await (0, _logo.default)();
    argv.log.debug(['Paths:', `▸ cwd: ${argv.cwd}`, `▸ cfg: ${argv.cfg}`, `▸ tpl: ${argv.tpl}`, '']);
    const hasPackage = await (0, _access.default)((0, _path.join)(argv.cwd, 'package.json'));

    if (hasPackage) {
      throw new Error('The project is already initialized');
    }

    const hasGitFolder = await (0, _access.default)((0, _path.join)(argv.cwd, '.git'));
    const options = (0, _settings.default)(argv); // NPM

    await (0, _spinner.spinnerAction)((0, _init2.default)(argv, {
      settings: options.packageInit
    }), 'Create the package.json');
    const packageName = await (0, _packageLoad.default)(argv, {
      key: 'name',
      throwError: true
    });

    if (typeof packageName !== 'string') {
      throw new TypeError('Package name could not be read');
    }

    options.packageUpdate.main = `build/${packageName}.js`;

    if (argv.cli) {
      options.packageBin[packageName] = 'build/bin/index.js';
    }

    await (0, _spinner.spinnerAction)((0, _init.default)(argv), 'Create the git repository');
    await (0, _io.default)(argv, options);
    await (0, _template.default)(argv, options, packageName);
    await (0, _dependencie.default)(argv, options); // UPDATE PACKAGE.JSON

    await (0, _spinner.spinnerAction)((0, _packageUpdate.default)(argv, {
      settings: { ...options.packageUpdate,
        bin: options.packageBin,
        scripts: options.packageScripts,
        peerDependencies: options.packagePeerDependencies
      }
    }), 'Update the package.json');

    if (!argv.noCommit && !hasGitFolder) {
      // GIT ADD
      await (0, _spinner.spinnerAction)((0, _add.default)(argv, {
        files: ['.']
      }), 'Add files to repository'); // GIT COMMIT

      await (0, _spinner.spinnerAction)((0, _commit.default)(argv, {
        msg: 'feat: 🐣'
      }), 'Create the initial commit');
    }
  } catch (error) {
    (0, _yargs.errorHandler)(argv, error);
  }
};

exports.handler = handler;