"use strict";

var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");

var _interopRequireWildcard = require("@babel/runtime-corejs3/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");

_Object$defineProperty(exports, "__esModule", {
  value: true
});

exports.handler = exports.builder = exports.desc = exports.command = void 0;

var _eslint = _interopRequireDefault(require("../actions/tools/eslint"));

var _prettier = _interopRequireWildcard(require("../actions/tools/prettier"));

var _tsc = _interopRequireDefault(require("../actions/tools/tsc"));

var _spinner = require("../lib/cli/spinner");

var _yargs = require("../lib/cli/yargs");

var _logo = _interopRequireDefault(require("../lib/logo"));

const command = 'lint';
exports.command = command;
const desc = 'Run the code quality tools';
exports.desc = desc;
const services = ['eslint', 'prettier', 'typescript'];
const options = {
  group: `${command}-Options`
};
const builder = (0, _yargs.builderDefault)(command, yargs => yargs.options({
  ci: { ...options,
    type: 'boolean',
    default: false,
    describe: 'Run it in CI mode'
  },
  only: { ...options,
    choices: services,
    implies: 'ci',
    describe: 'Run a single code quality tool'
  }
}));
exports.builder = builder;

const handler = async argv => {
  try {
    if (argv.ci) {
      if (typeof argv.only === 'undefined' || argv.only === 'prettier') {
        await (0, _prettier.default)(argv, {
          write: false,
          extension: _prettier.extensionCi
        });
      }

      if (typeof argv.only === 'undefined' || argv.only === 'eslint') {
        await (0, _eslint.default)(argv, {
          write: false
        });
      }

      if (typeof argv.only === 'undefined' || argv.only === 'typescript') {
        await (0, _tsc.default)(argv, {
          mode: 'type-check'
        });
      }
    } else {
      await (0, _logo.default)();
      argv.log.debug(['Paths:', `▸ cwd: ${argv.cwd}`, `▸ cfg: ${argv.cfg}`, `▸ tpl: ${argv.tpl}`, '']);
      await (0, _spinner.spinnerAction)((0, _prettier.default)(argv, {
        write: true
      }), 'Prettier');
      await (0, _spinner.spinnerAction)((0, _eslint.default)(argv, {
        write: true
      }), 'Eslint');
      await (0, _spinner.spinnerAction)((0, _tsc.default)(argv, {
        mode: 'type-check'
      }), 'Typescript');
    }
  } catch (error) {
    (0, _yargs.errorHandler)(argv, error);
  }
};

exports.handler = handler;